import { Topping, Pizza, ChangePizzaDto, Maybe } from "../generated/graphql";
import { PizzaList } from "../data/pizza-list";
import { v4 as uuidv4 } from 'uuid';
import { ToppingResolver } from "./topping-resolver";

export class PizzaResolver {

    static getById = (id: string): Pizza => {
        return PizzaList.filter(pizza => pizza.id === id)[0];
    };

    static list = (): Pizza[] => {
        return PizzaList;
    };

    static getByName = (name: string): Pizza => {
        return PizzaList.filter(pizza => pizza.name === name)[0];
    };

    static create = (pizzaCreateDto: ChangePizzaDto): Pizza => {
        const toppings: Topping[] = pizzaCreateDto.toppingIds
            .map<string>((toppingId) => toppingId as string)
            .map<Topping>((toppingId) => ToppingResolver.getById(toppingId));
        const pizza: Pizza = {
            id: uuidv4(),
            name: pizzaCreateDto.name,
            toppings: toppings
        }
        console.log(`Create Pizza ...`, pizza)
        return pizza;
    };

    static update = (pizzaId: string, pizzaUpdateDto: ChangePizzaDto): Pizza => {
        const pizza = PizzaResolver.getById(pizzaId);
        if (!pizza) {
            throw new Error(
                `No Pizza found with id ${pizzaId}`
            )
        }
        const toppings: Topping[] = pizzaUpdateDto.toppingIds
            .map<string>((toppingId: Maybe<string>) => toppingId as string)
            .map<Topping>((toppingId: string) => ToppingResolver.getById(toppingId));
        pizza.name = pizzaUpdateDto.name;
        pizza.toppings = toppings;
        console.log(`Update Pizza ...`, pizza)
        return pizza;
    };

}